@@ -468,6 +468,15 @@ def initialize(backends=("libOpenCL.so", "OpenCL.dll")):
                                    cl_uint num_events_in_wait_list,
                                    const cl_event *event_wait_list,
                                    cl_event *event);
+    cl_int clEnqueueFillBuffer(cl_command_queue command_queue,
+                               cl_mem buffer,
+                               const void *pattern,
+                               size_t pattern_size,
+                               size_t offset,
+                               size_t size,
+                               cl_uint num_events_in_wait_list,
+                               const cl_event *event_wait_list,
+                               cl_event *event);
 
     cl_int clWaitForEvents(cl_uint num_events,
                            const cl_event *event_list);
@@ -521,6 +530,22 @@ def initialize(backends=("libOpenCL.so", "OpenCL.dll")):
     cl_int clSetKernelArgSVMPointer(cl_kernel kernel,
                                     cl_uint arg_index,
                                     const void *arg_value);
+    cl_int clEnqueueSVMMemcpy(cl_command_queue command_queue,
+                              cl_bool blocking_copy,
+                              void *dst_ptr,
+                              const void *src_ptr,
+                              size_t size,
+                              cl_uint num_events_in_wait_list,
+                              const cl_event *event_wait_list,
+                              cl_event *event);
+    cl_int clEnqueueSVMMemFill(cl_command_queue command_queue,
+                               void *svm_ptr,
+                               const void *pattern,
+                               size_t pattern_size,
+                               size_t size,
+                               cl_uint num_events_in_wait_list,
+                               const cl_event *event_wait_list,
+                               cl_event *event);
     """
 
     # Parse
