@@ -592,6 +592,33 @@ class Test(unittest.TestCase):
         diff = numpy.fabs(c[8:28, 7:17, 6:11] - a[5:25, 4:14, 3:8]).max()
         self.assertEqual(diff, 0)
 
+    def test_fill_buffer(self):
+        # Create platform, context and queue
+        platforms = cl.Platforms()
+        ctx = platforms.create_some_context()
+        if ctx.devices[0].version < 1.2:
+            return
+        queue = ctx.create_queue(ctx.devices[0])
+
+        import numpy
+
+        # Create array
+        a = numpy.zeros(4096, dtype=numpy.int32)
+
+        # Create buffer
+        a_ = ctx.create_buffer(cl.CL_MEM_READ_WRITE | cl.CL_MEM_COPY_HOST_PTR,
+                               a)
+
+        # Fill the buffer
+        pattern = numpy.array([1, 2, 3, 4], dtype=numpy.int32)
+        queue.fill_buffer(a_, pattern, pattern.nbytes, a.nbytes).wait()
+
+        queue.read_buffer(a_, a)
+        diff = 0
+        for i in range(0, a.size, pattern.size):
+            diff += numpy.fabs(a[i:i + pattern.size] - pattern).sum()
+        self.assertEqual(diff, 0)
+
     def test_set_arg_None(self):
         import numpy
         # Create platform, context, program, kernel and queue
@@ -799,6 +826,42 @@ class Test(unittest.TestCase):
             pass
         del svm  # svm destructor here
 
+    def test_svm_memcpy(self):
+        ctx = cl.Platforms().create_some_context()
+        if ctx.devices[0].version < 2.0:
+            return
+        svm = ctx.svm_alloc(cl.CL_MEM_READ_WRITE, 4096)
+        import numpy
+        a = numpy.frombuffer(svm.buffer, dtype=numpy.int32)
+        queue = ctx.create_queue(ctx.devices[0])
+        queue.svm_map(svm, cl.CL_MAP_WRITE_INVALIDATE_REGION, svm.size)
+        a[:] = numpy.arange(a.size, dtype=a.dtype)
+        queue.svm_unmap(svm)
+        n = a.size // 2
+        queue.svm_memcpy(a[n:], a, n * a.itemsize)
+        queue.svm_map(svm, cl.CL_MAP_READ, svm.size)
+        self.assertEqual(numpy.fabs(a[n:] - a[:n]).max(), 0)
+        queue.svm_unmap(svm).wait()
+        del svm
+
+    def test_svm_memfill(self):
+        ctx = cl.Platforms().create_some_context()
+        if ctx.devices[0].version < 2.0:
+            return
+        svm = ctx.svm_alloc(cl.CL_MEM_READ_WRITE, 4096)
+        import numpy
+        a = numpy.frombuffer(svm.buffer, dtype=numpy.int32)
+        queue = ctx.create_queue(ctx.devices[0])
+        pattern = numpy.array([1, 2, 3, 4], dtype=numpy.int32)
+        queue.svm_memfill(a, pattern, pattern.nbytes, a.nbytes)
+        queue.svm_map(svm, cl.CL_MAP_READ, svm.size)
+        diff = 0
+        for i in range(0, a.size, pattern.size):
+            diff += numpy.fabs(a[i:i + pattern.size] - pattern).sum()
+        self.assertEqual(diff, 0)
+        queue.svm_unmap(svm).wait()
+        del svm
+
 
 if __name__ == "__main__":
     unittest.main()
